#!/usr/bin/python

import sys, os.path, ao

sys.path.insert(0, "build/lib.linux-ppc-2.3")

print sys.path

import mad
import urllib

def play(u):
    mf = mad.MadFile(u)
    
    if mf.layer() == mad.LAYER_I:
        print "MPEG Layer I"
    elif mf.layer() == mad.LAYER_II:
        print "MPEG Layer II"
    elif mf.layer() == mad.LAYER_III:
        print "MPEG Layer III"
    else:
        print "unexpected layer value"
        
    if mf.mode() == mad.MODE_SINGLE_CHANNEL:
        print "single channel"
    elif mf.mode() == mad.MODE_DUAL_CHANNEL:
        print "dual channel"
    elif mf.mode() == mad.MODE_JOINT_STEREO:
        print "joint (MS/intensity) stereo"
    elif mf.mode() == mad.MODE_STEREO:
        print "normal L/R stereo"
    else:
        print "unexpected mode value"
            
    if mf.emphasis() == mad.EMPHASIS_NONE:
        print "no emphasis"
    elif mf.emphasis() == mad.EMPHASIS_50_15_US:
        print "50/15us emphasis"
    elif mf.emphasis() == mad.EMPHASIS_CCITT_J_17:
        print "CCITT J.17 emphasis"
    else:
        print "unexpected emphasis value"
        
    print "bitrate %lu bps" % mf.bitrate()
    print "samplerate %d Hz" % mf.samplerate()
    #millis = mf.total_time()
    #secs = millis / 1000
    #print "total time %d ms (%dm%2ds)" % (millis, secs / 60, secs % 60)
        
    dev = ao.AudioDevice('oss', bits=16, rate=mf.samplerate())
    while 1:
        buffy = mf.read()
        if buffy is None:
            break
        dev.play(buffy, len(buffy))
        #print "current time: %d ms" % mf.current_time()

if __name__ == "__main__":
    print "pymad version %s" % mad.__version__
    for file in sys.argv[1:]:
        u = urllib.urlopen(file)
        if u:
        #if os.path.exists(file):
            print "playing %s" % file
            play(u)



#! /usr/bin/env python

import sys, os.path

sys.path.insert(0, "build/lib.linux-ppc-2.3")

import socket, urlparse
import mad, ao

def madradio(url):
    scheme, netloc, path, params, query, fragment = urlparse.urlparse(url)
    try:
        host, port = netloc.split(':')
    except ValueError:
        host, port = netloc, 80
    if not path:
        path = '/'
    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
    sock.connect((host, int(port)))
    sock.send('GET %s HTTP/1.0\r\n\r\n' % path)
    reply = sock.recv(1500)
    #print repr(reply)
    file = sock.makefile()
    mf = mad.MadFile(file)
    print "bitrate %lu bps" % mf.bitrate()
    print "samplerate %d Hz" % mf.samplerate()
    dev = ao.AudioDevice('oss', bits=16, rate=mf.samplerate())
    while True:
        buffy = mf.read()
        if buffy is None:
            break
        dev.play(buffy, len(buffy))

if __name__ == '__main__':
    import sys
    try:
        url = sys.argv[1]
    except IndexError:
        #url = 'http://62.67.195.6:8000' # lounge-radio.com
        url = 'http://63.241.4.18:8069' # xtcradio.com
    madradio(url)



#!/usr/bin/env python

import string
import os
import sys

def msg_checking(msg):
    print "Checking", msg, "...",

def execute(cmd, display = 0):
    if display:
        print cmd
    return os.system(cmd)

def run_test(input, flags = ''):
    try:
        f = open('_temp.c', 'w')
        f.write(input)
        f.close()
        compile_cmd = '%s -o _temp _temp.c %s' % (os.environ.get('CC', 'cc'),
                                                  flags)
        if not execute(compile_cmd):
            execute('./_temp')
    finally:
        execute('rm -f _temp.c _temp')
    
mad_test_program = '''
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <mad.h>

int main ()
{
  system("touch conf.madtest");
  return 0;
}
'''

def find_mad(mad_prefix = '/usr/local', enable_madtest = 1):
    """A rough translation of mad.m4"""

    mad_cflags = []
    mad_libs = []
    
    mad_include_dir = mad_prefix + '/include'
    mad_lib_dir = mad_prefix + '/lib'
    mad_libs = 'mad'

    msg_checking('for MAD')

    if enable_madtest:
        execute('rm -f conf.madtest', 0)

        try:
            run_test(mad_test_program, flags="-I" + mad_include_dir)
            if not os.path.isfile('conf.madtest'):
                raise RuntimeError, "Did not produce output"
            execute('rm conf.madtest', 0)
            
        except:
            print "test program failed"
            return None

    print "success"

    return {'mad_libs' : mad_libs,
            'mad_lib_dir' : mad_lib_dir,
            'mad_include_dir' : mad_include_dir}

endian_test_program = '''
#include <stdio.h>

int litend() {
  int i = 0;
  ((char *)(&i))[0] = 1;
  return(i == 1);
}

int bigend() {
  return !litend();
}

int main() {
  if (litend()) {
    system("touch little.endiantest");
  } else {
    system("touch big.endiantest");
  }
}
'''

def check_endian(enable_endiantest = 1):
    """check the system for endianness"""

    bigendian = 1

    msg_checking('endianness')

    if enable_endiantest:
        try:
            run_test(endian_test_program)
            if os.path.isfile("little.endiantest"):
                bigendian = 0
            elif os.path.isfile("big.endiantest"):
                bigendian = 1
            else:
                raise RuntimeError, "Did not produce output"
            execute("rm -f little.endiantest big.endiantest", 0)
        except:
            print "test program failed"
            return None

    print "success"

    return bigendian
            

def write_data(data):
    f = open('Setup', 'w')
    for item in data.items():
        f.write('%s = %s\n' % item)
    f.close()
    print "Wrote Setup file"
            
def print_help():
    print '''%s
    --prefix      Give the prefix in which MAD was installed.''' % sys.argv[0]
    sys.exit(0)

def parse_args():
    data = {}
    argv = sys.argv
    for pos in range(len(argv)):
        if argv[pos] == '--help':
            print_help()
        if argv[pos] == '--prefix':
            pos = pos + 1
            if len(argv) == pos:
                print "Prefix needs an argument"
                sys.exit(1)
            data['prefix'] = argv[pos]

    return data
    
def main():
    args = parse_args()
    prefix = args.get('prefix', '/usr/local')

    data = find_mad(mad_prefix = prefix)
    if not data:
        print "Config failure"
        sys.exit(1)
    if check_endian() == 1:
        data["endian"] = "big"
    else:
        data["endian"] = "little"
    write_data(data)

if __name__ == '__main__':
    main()







#!/usr/bin/env python

"""Setup script for the MAD module distribution."""

import os, re, sys, string

from distutils.core import setup
from distutils.extension import Extension

VERSION_MAJOR = 0
VERSION_MINOR = 6
pymad_version = str(VERSION_MAJOR) + "." + str(VERSION_MINOR)

def get_setup():
    data = {}
    r = re.compile(r'(\S+)\s*=\s*(.+)')
    
    if not os.path.isfile('Setup'):
        print "No 'Setup' file. Perhaps you need to run the configure script."
        sys.exit(1)
        
    f = open('Setup', 'r')
        
    for line in f.readlines():
        m = r.search(line)
        if not m:
            print "Error in setup file:", line
            sys.exit(1)
        key = m.group(1)
        val = m.group(2)
        data[key] = val
        
    return data

data = get_setup()

defines = [('VERSION_MAJOR', VERSION_MAJOR),
           ('VERSION_MINOR', VERSION_MINOR),
           ('VERSION', '"%s"' % pymad_version)]

if data['endian'] == "big":
    defines.append(('BIGENDIAN', 1))

madmodule = Extension(
    name='madmodule',
    sources=['src/madmodule.c', 'src/pymadfile.c', 'src/xing.c'],
    define_macros = defines,
    include_dirs=[data['mad_include_dir']],
    library_dirs=[data['mad_lib_dir']],
    libraries=string.split(data['mad_libs']))

setup ( # Distribution metadata
    name = "pymad",
    version = pymad_version,
    description = "A wrapper for the MAD libraries.",
    author = "Jamie Wilkinson",
    author_email = "jaq@spacepants.org",
    url = "http://spacepants.org/src/pymad/",
    license = "GPL",
    
    ext_modules = [madmodule])



#! /usr/bin/python

import sys

sys.path.insert(0, "build/lib.linux-ppc-2.3")

import mad, StringIO

data = StringIO.StringIO(open("foo.mp3","r").read())
m = mad.MadFile(data)
print "MadFile returned"
for x in (1,2): pass
print "got here"

